==> apache-drill-1.17.0-src.zip: apache-drill-1.17.0-src/metastore/metastore-api/src/main/java/org/apache/drill/metastore/config/MetastoreConfigConstants.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.drill.metastore.config;

/**
 * Holds Metastore configuration files names and their properties names.
 */
public interface MetastoreConfigConstants {

  /**
   * Indicates file which provides default Metastore configuration, usually shipped in the project.
   */
  String DEFAULT_RESOURCE_FILE_NAME = "drill-metastore-default.conf";

  /**
   * Indicates file which provides configuration of the Metastore implementations,
   * usually shipped with Metastore implementations.
   */
  String MODULE_RESOURCE_FILE_NAME = "drill-metastore-module.conf";

  /**
   * Indicates file which provides distribution specific Metastore configuration.
   */
  String DISTRIBUTION_RESOURCE_FILE_NAME = "drill-metastore-distrib.conf";

  /**
   * Indicates file which can override default Metastore configuration
   * or Metastore implementations configuration.
   */
  String OVERRIDE_RESOURCE_FILE_NAME = "drill-metastore-override.conf";


  /**
   * Metastore configuration properties namespace.
   */
  String BASE = "drill.metastore.";

  /**
   * Indicates canonical class name of the Metastore implementation class.
   */
  String IMPLEMENTATION_CLASS = BASE + "implementation.class";
}

==> apache-drill-1.22.0-src.zip: apache-drill-1.22.0-src/metastore/metastore-api/src/main/java/org/apache/drill/metastore/config/MetastoreConfigConstants.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.drill.metastore.config;

/**
 * Holds Metastore configuration files names and their properties names.
 */
public interface MetastoreConfigConstants {

  /**
   * Indicates file which provides default Metastore configuration, usually shipped in the project.
   */
  String DEFAULT_RESOURCE_FILE_NAME = "drill-metastore-default.conf";

  /**
   * Indicates file which provides configuration of the Metastore implementations,
   * usually shipped with Metastore implementations.
   */
  String MODULE_RESOURCE_FILE_NAME = "drill-metastore-module.conf";

  /**
   * Indicates file which provides distribution specific Metastore configuration.
   */
  String DISTRIBUTION_RESOURCE_FILE_NAME = "drill-metastore-distrib.conf";

  /**
   * Indicates file which can override default Metastore configuration
   * or Metastore implementations configuration.
   */
  String OVERRIDE_RESOURCE_FILE_NAME = "drill-metastore-override.conf";

  /**
   * Metastore configuration properties namespace.
   */
  String BASE = "drill.metastore.";

  /**
   * Indicates canonical class name of the Metastore implementation class.
   */
  String IMPLEMENTATION_CLASS = BASE + "implementation.class";

  /**
   * Indicates if provided Drill config should be used without looking for overridden / fallback
   * resource files in the classpath. Used for testing only.
   */
  String USE_PROVIDED_CONFIG = BASE + "config.use_provided";
}
